==> simg-1.0.0.23.zip: simg-project/application/view/compile/00cfb608aa9557cf36d5c188b214952f34ffc112.file.styles.css.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-04-28 14:01:50
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\styles.css.tpl" */ ?>
<?php /*%%SmartyHeaderCode:29586553f76aea159d2-17678968%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '00cfb608aa9557cf36d5c188b214952f34ffc112' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\styles.css.tpl',
      1 => 1430222079,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '29586553f76aea159d2-17678968',
  'function' => 
  array (
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_553f76aea5bee5_62713733',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_553f76aea5bee5_62713733')) {function content_553f76aea5bee5_62713733($_smarty_tpl) {?>{* included this style .. as an experiment *}
@CHARSET "UTF-8";<br/>

body{
	font-family:Times New Roman , "游明朝", YuMincho, "ヒラギノ明朝 ProN W3", Hiragino Mincho ProN , "MSP明朝","MS PMincho","MS 明朝",serif;
	font-size: 90%;
	text-align:center;
	padding: 0;
	margin: 0;
}

#wrapper {
	text-align: left;
	width: 800px;
	margin: 0 auto 0 auto;
	padding: 0;
}
#header {
	height: 100px;
	margin: 0.5em 0 0 0;
	padding: 0.5em 0;
	font-size: xx-large;
	text-align: center;
	border:1px solid #999999;
	border-radius:10px;
	text-decoration:none;
	color:#0066ff;
}
#header a {
	text-decoration:none;
	color:#0066ff;
}
#commandbar {
	margin-top:5px;
	text-align: right;
	color:#666666;
}
#commandbar a {
	text-decoration:none;
	margin-left: 1.0em;
	color:#848684;
}
#commandbar a:hover {
	text-decoration:none;
	margin-left: 1.0em;
	color:#ff8f6f;
}
#container {
	position: relative;
	width: 100%;
	margin: 0.5em 0 0 0;
	padding: 0;
	height: 350px;
	min-height: 350px;
	display: table;
}
#contents {
	margin: 0 0 0 200px;
	padding: 0.5em;
}
#sidebar {
	width: 180px;
	margin: 0 0 0 0;
	padding: 0.5em;
	position: absolute;
	top: 0;
	left: 0;
}
#footer {
	text-align: center;
	margin: 0.5em 0 0 0;
	padding: 0.5em;
	border-top: 1px solid #666666;
}
#error_message {
	color: #ff0000;
}
ul#navi, ul#navi * {
	font:bold 11px Verdana, sans-serif;
	margin:0;
	padding:0;
	line-height:1em;
}
ul#navi {
	margin:1em 0;
	padding:0;
	line-height:1em;
	list-style:none;
}
ul#navi li {
	margin:0;
	padding:0;
	line-height:0;
	text-align:left;
}
ul#navi a:hover {
    color:#ff8f6f;
    border-left:5px solid #e3db9d;
    text-decoration:none;
}
ul#navi a {
	display:block;
	margin:0;
	padding:5px 10px;
	color:#848684; font-weight:bold;
	border-left:5px solid #eee;
	text-decoration:none;
}
ul#navi li#current a {
	color:#333399;
	border-left:5px solid #d1eac4;
	text-decoration:none;
}
#openarea {
	display: table-cell;
	vertical-align: middle;
	text-align: center;
}

#article_detail_title {
	font-size: 150%;
	color:#333399; font-weight:bold;
}
#article_detail_content {
	font-size: 120%;
	color:#333333;
	border-top:1px solid #999999;
	padding-top: 7px;
	margin-bottom: 10px;
}
#article_title a {
	font-size: 120%;
	color:#333399; font-weight:bold;
	text-decoration:none;
}
#article_title a:hover {
	font-size: 120%;
	color:#993333; font-weight:bold;
	text-decoration:none;
}
#article_date {
	color:#999999;
	float: right;
}
.clear_right {
	clear:right;
}
#article_pager_back {
	color:#666666;
	float: left;
}
#article_pager_next {
	color:#666666;
	float: right;
}
#to_back {
	color:#666666;
	float: right;
}
#like {
	float: left;
}
#like input {
	color: #333333;
}
#like_situation, #like_value {
	color:#333333;
	vertical-align: middle;
}
#article_pager_next a, #article_pager_back a, #to_back a {
	text-decoration:none;
}
#article_pager_next a:hover, #article_pager_back a:hover, #to_back a:hover {
	color:#ff9999;
	text-decoration:none;
}
.clear_both {
	clear:both;
}
<?php }} ?>

==> simg-2.0.33.zip: simg-project/application/view/compile/00cfb608aa9557cf36d5c188b214952f34ffc112.file.styles.css.tpl.php <==
<?php /* Smarty version Smarty-3.1.19, created on 2015-05-30 13:25:20
         compiled from "C:\Users\yoshitake\Documents\User\products\simg\develop\simg-project\application\view\template\styles.css.tpl" */ ?>
<?php /*%%SmartyHeaderCode:29586553f76aea159d2-17678968%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    '00cfb608aa9557cf36d5c188b214952f34ffc112' => 
    array (
      0 => 'C:\\Users\\yoshitake\\Documents\\User\\products\\simg\\develop\\simg-project\\application\\view\\template\\styles.css.tpl',
      1 => 1432985112,
      2 => 'file',
    ),
  ),
  'nocache_hash' => '29586553f76aea159d2-17678968',
  'function' => 
  array (
  ),
  'version' => 'Smarty-3.1.19',
  'unifunc' => 'content_553f76aea5bee5_62713733',
  'has_nocache_code' => false,
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_553f76aea5bee5_62713733')) {function content_553f76aea5bee5_62713733($_smarty_tpl) {?>@charset "utf-8";

body{
	font-family:Times New Roman , "游明朝", YuMincho, "ヒラギノ明朝 ProN W3", Hiragino Mincho ProN , "MSP明朝","MS PMincho","MS 明朝",serif;
	font-size: 90%;
	text-align:center;
	padding: 0;
	margin: 0;
}

#wrapper {
	text-align: left;
	width: 800px;
	margin: 0 auto 0 auto;
	padding: 0;
}
#header {
	height: 100px;
	margin: 0.5em 0 0 0;
	padding: 0.5em 0;
	font-size: xx-large;
	text-align: center;
	border:1px solid #999999;
	border-radius:10px;
	text-decoration:none;
	color:#0066ff;
}
#header a {
	text-decoration:none;
	color:#0066ff;
}
#commandbar {
	margin-top:5px;
	text-align: right;
	color:#666666;
}
#commandbar a {
	text-decoration:none;
	margin-left: 1.0em;
	color:#848684;
}
#commandbar a:hover {
	text-decoration:none;
	margin-left: 1.0em;
	color:#ff8f6f;
}
#container {
	position: relative;
	width: 100%;
	margin: 0.5em 0 0 0;
	padding: 0;
	height: 350px;
	min-height: 350px;
	display: table;
}
#contents {
	margin: 0 0 0 200px;
	padding: 0.5em;
}
#sidebar {
	width: 180px;
	margin: 0 0 0 0;
	padding: 0.5em;
	position: absolute;
	top: 0;
	left: 0;
}
#footer {
	text-align: center;
	margin: 0.5em 0 0 0;
	padding: 0.5em;
	border-top: 1px solid #666666;
}
#error_message {
	color: #ff0000;
}
ul#navi, ul#navi * {
	font:bold 11px Verdana, sans-serif;
	margin:0;
	padding:0;
	line-height:1em;
}
ul#navi {
	margin:1em 0;
	padding:0;
	line-height:1em;
	list-style:none;
}
ul#navi li {
	margin:0;
	padding:0;
	line-height:0;
	text-align:left;
}
ul#navi a:hover {
    color:#ff8f6f;
    border-left:5px solid #e3db9d;
    text-decoration:none;
}
ul#navi a {
	display:block;
	margin:0;
	padding:5px 10px;
	color:#848684; font-weight:bold;
	border-left:5px solid #eee;
	text-decoration:none;
}
ul#navi li#current a {
	color:#333399;
	border-left:5px solid #d1eac4;
	text-decoration:none;
}
#openarea {
	display: table-cell;
	vertical-align: middle;
	text-align: center;
}

#article_detail_title {
	font-size: 150%;
	color:#333399; font-weight:bold;
}
#article_detail_content {
	font-size: 120%;
	color:#333333;
	border-top:1px solid #999999;
	padding-top: 7px;
	margin-bottom: 10px;
}
#article_title a {
	font-size: 120%;
	color:#333399; font-weight:bold;
	text-decoration:none;
}
#article_title a:hover {
	font-size: 120%;
	color:#993333; font-weight:bold;
	text-decoration:none;
}
#article_date {
	color:#999999;
	float: right;
}
.clear_right {
	clear:right;
}
#article_pager_back {
	color:#666666;
	float: left;
}
#article_pager_next {
	color:#666666;
	float: right;
}
#to_back {
	color:#666666;
	float: right;
}
#like {
	float: left;
}
#like input {
	color: #333333;
}
#like_situation, #like_value {
	color:#333333;
	vertical-align: middle;
}
#article_pager_next a, #article_pager_back a, #to_back a {
	text-decoration:none;
}
#article_pager_next a:hover, #article_pager_back a:hover, #to_back a:hover {
	color:#ff9999;
	text-decoration:none;
}
.clear_both {
	clear:both;
}
<?php }} ?>
